==> MediaWikiLanguageExtensionBundle-2012.12.tar.bz2: extensions/cldr/CldrNames/CldrNamesBm.php <==
<?php

$languageNames = array(
'ak' => 'akankan',
'am' => 'amarikikan',
'ar' => 'larabukan',
'be' => 'biyelorisikan',
'bg' => 'buligarikan',
'bm' => 'bamanakan',
'bn' => 'bɛngalikan',
'cs' => 'cɛkikan',
'de' => 'alimaɲikan',
'el' => 'gɛrɛsikan',
'en' => 'angilɛkan',
'es' => 'esipaɲolkan',
'fa' => 'perisanikan',
'fr' => 'tubabukan',
'ha' => 'awusakan',
'hi' => 'inidikan',
'hu' => 'oŋirikan',
'id' => 'Ɛndonezikan',
'ig' => 'igibokan',
'it' => 'italikan',
'ja' => 'zapɔnekan',
'jv' => 'javanekan',
'km' => 'kambojikan',
'ko' => 'korekan',
'ms' => 'malɛzikan',
'my' => 'birimanikan',
'ne' => 'nepalekan',
'nl' => 'olandekan',
'pa' => 'pɛnijabikan',
'pl' => 'polonekan',
'pt' => 'pɔritigalikan',
'ro' => 'rumanikan',
'ru' => 'irisikan',
'rw' => 'ruwandakan',
'so' => 'somalikan',
'sv' => 'suwɛdikan',
'ta' => 'tamulikan',
'th' => 'tayikan',
'tr' => 'turikikan',
'uk' => 'ukɛrɛnikan',
'ur' => 'urudukan',
'vi' => 'wiyɛtinamukan',
'yo' => 'yorubakan',
'zh' => 'siniwakan',
'zu' => 'zulukan',
);

$currencyNames = array(
'AED' => 'arabu mara kafoli Diram',
'AOA' => 'angola Kwanza',
'AUD' => 'ositirali Dolar',
'BHD' => 'bareyini Dinar',
'BIF' => 'burundi Fraŋ',
'BWP' => 'bɔtisiwana Pula',
'CAD' => 'kanada Dolar',
'CDF' => 'kongole Fraŋ',
'CHF' => 'suwisi Fraŋ',
'CNY' => 'siniwa Yuwan',
'CVE' => 'capivɛrdi Esekudo',
'DJF' => 'jibuti Fraŋ',
'DZD' => 'alizeri Dinar',
'EGP' => 'eziputi Livri',
'ERN' => 'eritere Nafika',
'ETB' => 'etiopi Bir',
'EUR' => 'ero',
'GBP' => 'angilɛ Livri Siterlingi',
'GHC' => 'gana Sedi',
'GMD' => 'gambi Dalasi',
'GNS' => 'gine Fraŋ',
'INR' => 'Ɛndu Rupi',
'JPY' => 'zapɔne Yɛn',
'KES' => 'keniya Siling',
'KMF' => 'komɔri Fraŋ',
'LRD' => 'liberiya Dolar',
'LSL' => 'lesoto Loti',
'LYD' => 'libi Dinar',
'MAD' => 'marɔku Diram',
'MGA' => 'madagasikari Fraŋ',
'MRO' => 'mɔritani Uguwiya',
'MUR' => 'morisi Rupi',
'MWK' => 'malawi Kwaca',
'MZM' => 'mozanbiki Metikali',
'NAD' => 'namibi Dolar',
'NGN' => 'nizeriya Nɛra',
'RWF' => 'ruwanda Fraŋ',
'SAR' => 'sawudiya Riyal',
'SCR' => 'sesɛli Rupi',
'SDG' => 'sudani Dinar',
'SDP' => 'sudani Livri',
'SHP' => 'Ɛlɛni-Senu Livri',
'SLL' => 'siyeralewɔni Lewɔni',
'SOS' => 'somali Siling',
'STD' => 'sawotome Dobra',
'SZL' => 'swazilandi Lilangeni',
'TND' => 'tunizi Dinar',
'TZS' => 'tanzani Siling',
'UGX' => 'uganda Siling',
'USD' => 'ameriki Dolar',
'XAF' => 'sefa Fraŋ (BEAC)',
'XOF' => 'sefa Fraŋ (BCEAO)',
'ZAR' => 'sudafriki Randi',
'ZMK' => 'zambi Kwaca',
'ZWD' => 'zimbabuwe Dolar',
);

$countryNames = array(
'AD' => 'Andɔr',
'AE' => 'Arabu mara kafoli',
'AF' => 'Afiganistaŋ',
'AG' => 'Antiga-ni-Barbuda',
'AI' => 'Angiya',
'AL' => 'Alibani',
'AM' => 'Arimeni',
'AN' => 'Peyiba ka Antiyi',
'AO' => 'Angola',
'AR' => 'Arizantin',
'AS' => 'Samowa amerikani',
'AT' => 'Otirisi',
'AU' => 'Ositirali',
'AW' => 'Aruba',
'AZ' => 'Azɛrbayjaŋ',
'BA' => 'Bozni-Ɛrizigovini',
'BB' => 'Barbadi',
'BD' => 'Bɛngiladɛsi',
'BE' => 'Bɛliziki',
'BF' => 'Burukina Faso',
'BG' => 'Buligari',
'BH' => 'Bareyini',
'BI' => 'Burundi',
'BJ' => 'Benɛn',
'BM' => 'Bermudi',
'BN' => 'Burinɛyi',
'BO' => 'Bolivi',
'BR' => 'Berezili',
'BS' => 'Bahamasi',
'BT' => 'Butaŋ',
'BW' => 'Bɔtisiwana',
'BY' => 'Belarusi',
'BZ' => 'Belizi',
'CA' => 'Kanada',
'CD' => 'Kongo ka republiki demɔkratiki',
'CF' => 'Santarafiriki',
'CG' => 'Kongo',
'CH' => 'Suwisi',
'CI' => 'Kodiwari',
'CK' => 'Kuki Gun',
'CL' => 'Sili',
'CM' => 'Kameruni',
'CN' => 'Siniwajamana',
'CO' => 'Kolombi',
'CR' => 'Kɔsitarika',
'CU' => 'Kuba',
'CV' => 'Capivɛrdi',
'CY' => 'Cipri',
'CZ' => 'Ceki republiki',
'DE' => 'Alimaɲi',
'DJ' => 'Jibuti',
'DK' => 'Danemarki',
'DM' => 'Dɔminiki',
'DO' => 'Dɔmimiki republiki',
'DZ' => 'Alizeri',
'EC' => 'Ekwatɔr',
'EE' => 'Esetoni',
'EG' => 'Eziputi',
'ER' => 'Eritere',
'ES' => 'Esipaɲi',
'ET' => 'Etiopi',
'FI' => 'Finilandi',
'FJ' => 'Fiji',
'FK' => 'Maluwini Gun',
'FM' => 'Mikironesi',
'FR' => 'Faransi',
'GA' => 'Gabɔŋ',
'GB' => 'Angilɛtɛri',
'GD' => 'Granadi',
'GE' => 'Zeyɔrzi',
'GF' => 'Faransi ka gwiyani',
'GH' => 'Gana',
'GI' => 'Zibralitari',
'GL' => 'Gɔrɔhenelandi',
'GM' => 'Ganbi',
'GN' => 'Gine',
'GP' => 'Gwadelup',
'GQ' => 'Gine ekwatɔri',
'GR' => 'Gɛrɛsi',
'GT' => 'Gwatemala',
'GU' => 'Gwam',
'GW' => 'Gine Bisawo',
'GY' => 'Gwiyana',
'HN' => 'Hɔndirasi',
'HR' => 'Kroasi',
'HT' => 'Ayiti',
'HU' => 'Hɔngri',
'ID' => 'Ɛndonezi',
'IE' => 'Irilandi',
'IL' => 'Isirayeli',
'IN' => 'Ɛndujamana',
'IO' => 'Angilɛ ka ɛndu dugukolo',
'IQ' => 'Iraki',
'IR' => 'Iraŋ',
'IS' => 'Isilandi',
'IT' => 'Itali',
'JM' => 'Zamayiki',
'JO' => 'Zɔrdani',
'JP' => 'Zapɔn',
'KE' => 'Keniya',
'KG' => 'Kirigizisitaŋ',
'KH' => 'Kamboji',
'KI' => 'Kiribati',
'KM' => 'Komɔri',
'KN' => 'Kristɔfo-Senu-ni-Ɲevɛs',
'KP' => 'Kɛɲɛka Kore',
'KR' => 'Worodugu Kore',
'KW' => 'Kowɛti',
'KY' => 'Bama Gun',
'KZ' => 'Kazakistaŋ',
'LA' => 'Layosi',
'LB' => 'Libaŋ',
'LC' => 'Lusi-Senu',
'LI' => 'Lisɛnsitayini',
'LK' => 'Sirilanka',
'LR' => 'Liberiya',
'LS' => 'Lesoto',
'LT' => 'Lituyani',
'LU' => 'Likisanburu',
'LV' => 'Letoni',
'LY' => 'Libi',
'MA' => 'Marɔku',
'MC' => 'Monako',
'MD' => 'Molidavi',
'MG' => 'Madagasikari',
'MH' => 'Marisali Gun',
'MK' => 'Macedɔni',
'ML' => 'Mali',
'MM' => 'Myanimari',
'MN' => 'Moŋoli',
'MP' => 'Kɛɲɛka Mariyani Gun',
'MQ' => 'Maritiniki',
'MR' => 'Mɔritani',
'MS' => 'Moŋsera',
'MT' => 'Malti',
'MU' => 'Morisi',
'MV' => 'Maldivi',
'MW' => 'Malawi',
'MX' => 'Meksiki',
'MY' => 'Malɛzi',
'MZ' => 'Mozanbiki',
'NA' => 'Namibi',
'NC' => 'Kaledoni Koura',
'NE' => 'Nizɛri',
'NF' => 'Nɔrofoliki Gun',
'NG' => 'Nizeriya',
'NI' => 'Nikaragwa',
'NL' => 'Peyiba',
'NO' => 'Nɔriwɛzi',
'NP' => 'Nepali',
'NR' => 'Nawuru',
'NU' => 'Nyuwe',
'NZ' => 'Zelandi Koura',
'OM' => 'Omaŋ',
'PA' => 'Panama',
'PE' => 'Peru',
'PF' => 'Faransi ka polinezi',
'PG' => 'Papuwasi-Gine-Koura',
'PH' => 'Filipini',
'PK' => 'Pakisitaŋ',
'PL' => 'Poloɲi',
'PM' => 'Piyɛri-Senu-ni-Mikelɔŋ',
'PN' => 'Pitikarini',
'PR' => 'Pɔrotoriko',
'PS' => 'Palesitini',
'PT' => 'Pɔritigali',
'PW' => 'Palawu',
'PY' => 'Paraguwayi',
'QA' => 'Katari',
'RE' => 'Reyuɲɔŋ',
'RO' => 'Rumani',
'RU' => 'Irisi',
'RW' => 'Ruwanda',
'SA' => 'Arabiya Sawudiya',
'SB' => 'Salomo Gun',
'SC' => 'Sesɛli',
'SD' => 'Sudaŋ',
'SE' => 'Suwɛdi',
'SG' => 'Sɛngapuri',
'SH' => 'Ɛlɛni Senu',
'SI' => 'Sloveni',
'SK' => 'Slowaki',
'SL' => 'Siyera Lewɔni',
'SM' => 'Marini-Senu',
'SN' => 'Senegali',
'SO' => 'Somali',
'SR' => 'Surinami',
'ST' => 'Sawo Tome-ni-Prinicipe',
'SV' => 'Salivadɔr',
'SY' => 'Siri',
'SZ' => 'Swazilandi',
'TC' => 'Turiki Gun ni Kayiki',
'TD' => 'Cadi',
'TG' => 'Togo',
'TH' => 'Tayilandi',
'TJ' => 'Tajikisitani',
'TK' => 'Tokelo',
'TL' => 'Kɔrɔn Timɔr',
'TM' => 'Turikimenisitani',
'TN' => 'Tunizi',
'TO' => 'Tonga',
'TR' => 'Turiki',
'TT' => 'Trinite-ni-Tobago',
'TV' => 'Tuvalu',
'TW' => 'Tayiwani',
'TZ' => 'Tanzani',
'UA' => 'Ukɛrɛni',
'UG' => 'Uganda',
'US' => 'Ameriki',
'UY' => 'Urugwayi',
'UZ' => 'Uzebekisitani',
'VA' => 'Vatikaŋ',
'VC' => 'Vinisɛn-Senu-ni-Grenadini',
'VE' => 'Venezuwela',
'VG' => 'Angilɛ ka Sungurunnin Gun',
'VI' => 'Ameriki ka Sungurunnin Gun',
'VN' => 'Wiyɛtinamu',
'VU' => 'Vanuwatu',
'WF' => 'Walisi-ni-Futuna',
'WS' => 'Samowa',
'YE' => 'Yemɛni',
'YT' => 'Mayoti',
'ZA' => 'Worodugu Afriki',
'ZM' => 'Zanbi',
'ZW' => 'Zimbabuwe',
);

==> MediaWikiLanguageExtensionBundle-2013.05.tar.bz2: extensions/cldr/CldrNames/CldrNamesBm.php <==
<?php

$languageNames = array(
'ak' => 'akankan',
'am' => 'amarikikan',
'ar' => 'larabukan',
'be' => 'biyelorisikan',
'bg' => 'buligarikan',
'bm' => 'bamanakan',
'bn' => 'bɛngalikan',
'cs' => 'cɛkikan',
'de' => 'alimaɲikan',
'el' => 'gɛrɛsikan',
'en' => 'angilɛkan',
'es' => 'esipaɲolkan',
'fa' => 'perisanikan',
'fr' => 'tubabukan',
'ha' => 'awusakan',
'hi' => 'inidikan',
'hu' => 'oŋirikan',
'id' => 'Ɛndonezikan',
'ig' => 'igibokan',
'it' => 'italikan',
'ja' => 'zapɔnekan',
'jv' => 'javanekan',
'km' => 'kambojikan',
'ko' => 'korekan',
'ms' => 'malɛzikan',
'my' => 'birimanikan',
'ne' => 'nepalekan',
'nl' => 'olandekan',
'pa' => 'pɛnijabikan',
'pl' => 'polonekan',
'pt' => 'pɔritigalikan',
'ro' => 'rumanikan',
'ru' => 'irisikan',
'rw' => 'ruwandakan',
'so' => 'somalikan',
'sv' => 'suwɛdikan',
'ta' => 'tamulikan',
'th' => 'tayikan',
'tr' => 'turikikan',
'uk' => 'ukɛrɛnikan',
'ur' => 'urudukan',
'vi' => 'wiyɛtinamukan',
'yo' => 'yorubakan',
'zh' => 'siniwakan',
'zu' => 'zulukan',
);

$currencyNames = array(
'AED' => 'arabu mara kafoli Diram',
'AOA' => 'angola Kwanza',
'AUD' => 'ositirali Dolar',
'BHD' => 'bareyini Dinar',
'BIF' => 'burundi Fraŋ',
'BWP' => 'bɔtisiwana Pula',
'CAD' => 'kanada Dolar',
'CDF' => 'kongole Fraŋ',
'CHF' => 'suwisi Fraŋ',
'CNY' => 'siniwa Yuwan',
'CVE' => 'capivɛrdi Esekudo',
'DJF' => 'jibuti Fraŋ',
'DZD' => 'alizeri Dinar',
'EGP' => 'eziputi Livri',
'ERN' => 'eritere Nafika',
'ETB' => 'etiopi Bir',
'EUR' => 'ero',
'GBP' => 'angilɛ Livri Siterlingi',
'GHC' => 'gana Sedi',
'GMD' => 'gambi Dalasi',
'GNS' => 'gine Fraŋ',
'INR' => 'Ɛndu Rupi',
'JPY' => 'zapɔne Yɛn',
'KES' => 'keniya Siling',
'KMF' => 'komɔri Fraŋ',
'LRD' => 'liberiya Dolar',
'LSL' => 'lesoto Loti',
'LYD' => 'libi Dinar',
'MAD' => 'marɔku Diram',
'MGA' => 'madagasikari Fraŋ',
'MRO' => 'mɔritani Uguwiya',
'MUR' => 'morisi Rupi',
'MWK' => 'malawi Kwaca',
'MZM' => 'mozanbiki Metikali',
'NAD' => 'namibi Dolar',
'NGN' => 'nizeriya Nɛra',
'RWF' => 'ruwanda Fraŋ',
'SAR' => 'sawudiya Riyal',
'SCR' => 'sesɛli Rupi',
'SDG' => 'sudani Dinar',
'SDP' => 'sudani Livri',
'SHP' => 'Ɛlɛni-Senu Livri',
'SLL' => 'siyeralewɔni Lewɔni',
'SOS' => 'somali Siling',
'STD' => 'sawotome Dobra',
'SZL' => 'swazilandi Lilangeni',
'TND' => 'tunizi Dinar',
'TZS' => 'tanzani Siling',
'UGX' => 'uganda Siling',
'USD' => 'ameriki Dolar',
'XAF' => 'sefa Fraŋ (BEAC)',
'XOF' => 'sefa Fraŋ (BCEAO)',
'ZAR' => 'sudafriki Randi',
'ZMK' => 'zambi Kwaca (1968-2012)',
'ZMW' => 'zambi Kwaca',
'ZWD' => 'zimbabuwe Dolar',
);

$countryNames = array(
'AD' => 'Andɔr',
'AE' => 'Arabu mara kafoli',
'AF' => 'Afiganistaŋ',
'AG' => 'Antiga-ni-Barbuda',
'AI' => 'Angiya',
'AL' => 'Alibani',
'AM' => 'Arimeni',
'AN' => 'Peyiba ka Antiyi',
'AO' => 'Angola',
'AR' => 'Arizantin',
'AS' => 'Samowa amerikani',
'AT' => 'Otirisi',
'AU' => 'Ositirali',
'AW' => 'Aruba',
'AZ' => 'Azɛrbayjaŋ',
'BA' => 'Bozni-Ɛrizigovini',
'BB' => 'Barbadi',
'BD' => 'Bɛngiladɛsi',
'BE' => 'Bɛliziki',
'BF' => 'Burukina Faso',
'BG' => 'Buligari',
'BH' => 'Bareyini',
'BI' => 'Burundi',
'BJ' => 'Benɛn',
'BM' => 'Bermudi',
'BN' => 'Burinɛyi',
'BO' => 'Bolivi',
'BR' => 'Berezili',
'BS' => 'Bahamasi',
'BT' => 'Butaŋ',
'BW' => 'Bɔtisiwana',
'BY' => 'Belarusi',
'BZ' => 'Belizi',
'CA' => 'Kanada',
'CD' => 'Kongo ka republiki demɔkratiki',
'CF' => 'Santarafiriki',
'CG' => 'Kongo',
'CH' => 'Suwisi',
'CI' => 'Kodiwari',
'CK' => 'Kuki Gun',
'CL' => 'Sili',
'CM' => 'Kameruni',
'CN' => 'Siniwajamana',
'CO' => 'Kolombi',
'CR' => 'Kɔsitarika',
'CU' => 'Kuba',
'CV' => 'Capivɛrdi',
'CY' => 'Cipri',
'CZ' => 'Ceki republiki',
'DE' => 'Alimaɲi',
'DJ' => 'Jibuti',
'DK' => 'Danemarki',
'DM' => 'Dɔminiki',
'DO' => 'Dɔmimiki republiki',
'DZ' => 'Alizeri',
'EC' => 'Ekwatɔr',
'EE' => 'Esetoni',
'EG' => 'Eziputi',
'ER' => 'Eritere',
'ES' => 'Esipaɲi',
'ET' => 'Etiopi',
'FI' => 'Finilandi',
'FJ' => 'Fiji',
'FK' => 'Maluwini Gun',
'FM' => 'Mikironesi',
'FR' => 'Faransi',
'GA' => 'Gabɔŋ',
'GB' => 'Angilɛtɛri',
'GD' => 'Granadi',
'GE' => 'Zeyɔrzi',
'GF' => 'Faransi ka gwiyani',
'GH' => 'Gana',
'GI' => 'Zibralitari',
'GL' => 'Gɔrɔhenelandi',
'GM' => 'Ganbi',
'GN' => 'Gine',
'GP' => 'Gwadelup',
'GQ' => 'Gine ekwatɔri',
'GR' => 'Gɛrɛsi',
'GT' => 'Gwatemala',
'GU' => 'Gwam',
'GW' => 'Gine Bisawo',
'GY' => 'Gwiyana',
'HN' => 'Hɔndirasi',
'HR' => 'Kroasi',
'HT' => 'Ayiti',
'HU' => 'Hɔngri',
'ID' => 'Ɛndonezi',
'IE' => 'Irilandi',
'IL' => 'Isirayeli',
'IN' => 'Ɛndujamana',
'IO' => 'Angilɛ ka ɛndu dugukolo',
'IQ' => 'Iraki',
'IR' => 'Iraŋ',
'IS' => 'Isilandi',
'IT' => 'Itali',
'JM' => 'Zamayiki',
'JO' => 'Zɔrdani',
'JP' => 'Zapɔn',
'KE' => 'Keniya',
'KG' => 'Kirigizisitaŋ',
'KH' => 'Kamboji',
'KI' => 'Kiribati',
'KM' => 'Komɔri',
'KN' => 'Kristɔfo-Senu-ni-Ɲevɛs',
'KP' => 'Kɛɲɛka Kore',
'KR' => 'Worodugu Kore',
'KW' => 'Kowɛti',
'KY' => 'Bama Gun',
'KZ' => 'Kazakistaŋ',
'LA' => 'Layosi',
'LB' => 'Libaŋ',
'LC' => 'Lusi-Senu',
'LI' => 'Lisɛnsitayini',
'LK' => 'Sirilanka',
'LR' => 'Liberiya',
'LS' => 'Lesoto',
'LT' => 'Lituyani',
'LU' => 'Likisanburu',
'LV' => 'Letoni',
'LY' => 'Libi',
'MA' => 'Marɔku',
'MC' => 'Monako',
'MD' => 'Molidavi',
'MG' => 'Madagasikari',
'MH' => 'Marisali Gun',
'MK' => 'Macedɔni',
'ML' => 'Mali',
'MM' => 'Myanimari',
'MN' => 'Moŋoli',
'MP' => 'Kɛɲɛka Mariyani Gun',
'MQ' => 'Maritiniki',
'MR' => 'Mɔritani',
'MS' => 'Moŋsera',
'MT' => 'Malti',
'MU' => 'Morisi',
'MV' => 'Maldivi',
'MW' => 'Malawi',
'MX' => 'Meksiki',
'MY' => 'Malɛzi',
'MZ' => 'Mozanbiki',
'NA' => 'Namibi',
'NC' => 'Kaledoni Koura',
'NE' => 'Nizɛri',
'NF' => 'Nɔrofoliki Gun',
'NG' => 'Nizeriya',
'NI' => 'Nikaragwa',
'NL' => 'Peyiba',
'NO' => 'Nɔriwɛzi',
'NP' => 'Nepali',
'NR' => 'Nawuru',
'NU' => 'Nyuwe',
'NZ' => 'Zelandi Koura',
'OM' => 'Omaŋ',
'PA' => 'Panama',
'PE' => 'Peru',
'PF' => 'Faransi ka polinezi',
'PG' => 'Papuwasi-Gine-Koura',
'PH' => 'Filipini',
'PK' => 'Pakisitaŋ',
'PL' => 'Poloɲi',
'PM' => 'Piyɛri-Senu-ni-Mikelɔŋ',
'PN' => 'Pitikarini',
'PR' => 'Pɔrotoriko',
'PS' => 'Palesitini',
'PT' => 'Pɔritigali',
'PW' => 'Palawu',
'PY' => 'Paraguwayi',
'QA' => 'Katari',
'RE' => 'Reyuɲɔŋ',
'RO' => 'Rumani',
'RU' => 'Irisi',
'RW' => 'Ruwanda',
'SA' => 'Arabiya Sawudiya',
'SB' => 'Salomo Gun',
'SC' => 'Sesɛli',
'SD' => 'Sudaŋ',
'SE' => 'Suwɛdi',
'SG' => 'Sɛngapuri',
'SH' => 'Ɛlɛni Senu',
'SI' => 'Sloveni',
'SK' => 'Slowaki',
'SL' => 'Siyera Lewɔni',
'SM' => 'Marini-Senu',
'SN' => 'Senegali',
'SO' => 'Somali',
'SR' => 'Surinami',
'ST' => 'Sawo Tome-ni-Prinicipe',
'SV' => 'Salivadɔr',
'SY' => 'Siri',
'SZ' => 'Swazilandi',
'TC' => 'Turiki Gun ni Kayiki',
'TD' => 'Cadi',
'TG' => 'Togo',
'TH' => 'Tayilandi',
'TJ' => 'Tajikisitani',
'TK' => 'Tokelo',
'TL' => 'Kɔrɔn Timɔr',
'TM' => 'Turikimenisitani',
'TN' => 'Tunizi',
'TO' => 'Tonga',
'TR' => 'Turiki',
'TT' => 'Trinite-ni-Tobago',
'TV' => 'Tuvalu',
'TW' => 'Tayiwani',
'TZ' => 'Tanzani',
'UA' => 'Ukɛrɛni',
'UG' => 'Uganda',
'US' => 'Ameriki',
'UY' => 'Urugwayi',
'UZ' => 'Uzebekisitani',
'VA' => 'Vatikaŋ',
'VC' => 'Vinisɛn-Senu-ni-Grenadini',
'VE' => 'Venezuwela',
'VG' => 'Angilɛ ka Sungurunnin Gun',
'VI' => 'Ameriki ka Sungurunnin Gun',
'VN' => 'Wiyɛtinamu',
'VU' => 'Vanuwatu',
'WF' => 'Walisi-ni-Futuna',
'WS' => 'Samowa',
'YE' => 'Yemɛni',
'YT' => 'Mayoti',
'ZA' => 'Worodugu Afriki',
'ZM' => 'Zanbi',
'ZW' => 'Zimbabuwe',
);
